/*
 * test_mqconnu.c is a program to test MQCONNU API call.
 *
 * Input Parameters:
 *    QMgrName UserId Password
 *
 * Where
 *    QMgrName is the queue manager name
 *    UserId is the UserId to be authenticated
 *    Password is the password to be authenticated
 * i.e.
 *    test_mqconnu  MQWT1 roger mypwd
 *
 * @author Roger Lacroix, Capitalware Inc.
 * @version 1.00
 * @license Apache 2 License
 */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <cmqc.h>

#include "mqconnu.c" /* prototypes and code for MQCONNU and MQCONNUX */

/*
 *
 */
int main(int argc, char **argv)
{
   /* --------------------------------------------
    * Variable declarations.
    * --------------------------------------------
    */
   MQHCONN  Hcon;                   /* connection handle  */
   MQLONG   CompCode;               /* completion code    */
   MQLONG   Reason;                 /* reason code        */
   char     QMgrName[MQ_Q_MGR_NAME_LENGTH+1];
   char     userId[64];
   char     passwd[64];

   /* --------------------------------------------
    * Code section
    * --------------------------------------------
    */
   if (argc != 4)
   {
      printf("test_mqconnu QMgrName userid password\n");
      return(1);
   }

   printf("test_mqconnu start\n");

   strncpy(QMgrName, argv[1], MQ_Q_MGR_NAME_LENGTH);
   strncpy(userId, argv[2], sizeof(userId));
   strncpy(passwd, argv[3], sizeof(passwd));

   printf("Using values:\n");
   printf("   QMgrName   : %s\n", QMgrName);
   printf("   UserID     : %s\n", userId);
   printf("   Password   : %s\n", passwd);

   /* --------------------------------------------
    * Connect to queue manager
    * --------------------------------------------
    */
   MQCONNU(userId,                  /* UserId             */
           passwd,                  /* Password           */
           QMgrName,                /* queue manager      */
           &Hcon,                   /* connection handle  */
           &CompCode,               /* completion code    */
           &Reason);                /* reason code        */

   printf("MQCONNU CC=%d RC=%d\n", CompCode, Reason);

   /* --------------------------------------------
    * Disconnect from queue manager
    * --------------------------------------------
    */
   if (CompCode == MQCC_OK)
   {
      MQDISC(&Hcon,                 /* connection handle  */
             &CompCode,             /* completion code    */
             &Reason);              /* reason code        */

      printf("MQDISC  CC=%d RC=%d\n", CompCode, Reason);
   }

   printf("test_mqconnu end\n");
   return(0);
}
